# CHANGELOG


## v2.2.1 (2025-05-22)

### Bug Fixes

- Allow python 3.12 compatibility
  ([`da0b28b`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/da0b28b4799a12f858decb502c5ee8fee94defef))

### Documentation

- **license**: Update license statement to reflect internal release
  ([`15401ee`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/15401ee77a4499e8e823e623bfc90393fa01bf4c))


## v2.2.0 (2025-05-12)

### Features

- Update authors and maintainers
  ([`f6fc381`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/f6fc381f0a210e65f513c1224eb4fe15f467d8e6))


## v2.1.0 (2025-05-08)

### Bug Fixes

- Abs error mistake in bond fraction error handling
  ([`569c363`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/569c36369af20d8cd940b481a8f1d74c4b5a8228))

- Added error checking if symmetrical bonds do not have the same bond fraction value
  ([`54060e9`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/54060e9d3b4b1ebc22096a4b5d5eafafc5d24c60))

- Correct error logic flow
  ([`8e71277`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/8e71277a3e7be199850e993871c0ea6a2132589c))

- Correct error message
  ([`a6dae6c`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/a6dae6c17277b65778fc619694bda37700fa5253))

- Correct error message
  ([`942b112`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/942b1122a6267d5741283ca68fedc243d34ad46d))

- Error handling logic of bond fractions for SilicateBinarySlagEquilibriumTxState and
  SilicateSlagEquilibriumTxState classes
  ([`1cd5c6f`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/1cd5c6fb0753c0c8094f54860e09c46ae188a7ec))

- Fix density binary model bug
  ([`beb7b89`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/beb7b890e26c07f801e4cdd02da9ac297f6c16de))

- Fix mistake with error handling loop
  ([`3b6b3e6`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/3b6b3e67c17343d33295b9f903228794443f89e6))

- Mistake in error handling for bond fractions
  ([`fefb778`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/fefb77813c975332a9aed08c182064ac7688e586))

### Chores

- Add Kim's way of calculating p
  ([`c4b6b09`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/c4b6b090f3a139a9e5150950f91fef06de565f63))

- Add missing parameters
  ([`05f8cc3`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/05f8cc3a8855d3ebf6ba0200367c7b6963fdffda))

- Add new viscosity model
  ([`a1fae82`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/a1fae8252412abfca689991ef946ab3d379c3801))

- Add p input
  ([`e1c1fa5`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/e1c1fa59e482f5cccc88c259ab18ef3754f5ee72))

- Add p input
  ([`4ec1c11`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/4ec1c11756f422c02d8c02f58d2b6f047c6ec89e))

- Add p input
  ([`a698664`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/a6986643f23cbde7ec84be3ec88401de267a4207))

- Add p input
  ([`d178f83`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/d178f83fc8a51c43dca6a6528b8ff5b51d699ea8))

- Add p input
  ([`33e0094`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/33e0094ec483770c4b673dcc11d74bf737ebb676))

- Add p input
  ([`9ef8d89`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/9ef8d895923978d696970e1ab5d55b2a64b5e0c5))

- Add p to bff input
  ([`13afddd`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/13afddde1ad51dfec716667d851f9b59a3e4ab4b))

- Add p to bff input
  ([`70359bf`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/70359bfc4dc0556de25f4aa24efe7c509fb0dcf2))

- Add p to bff input
  ([`c1ba21b`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/c1ba21b261543f36e27a5c39a12bec09aa462ab4))

- Add p to bff input
  ([`f005656`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/f005656bdee258a8a643a0f4050bb6478ee8b8b0))

- Add p to bff input
  ([`1f60a7b`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/1f60a7b7c137ab02a82e36643b32ad788af34a1b))

- Add p to bff input
  ([`867f5a1`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/867f5a1c43abf54fe90de85bc87c83d8a4eced47))

- Add print statements in mass balance check
  ([`020b3f6`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/020b3f6e7b0314b68cf1447bcb587970ce7c6de6))

- Add scipy-stubs .tmol file's dev dependency and removed the typings/scipy folder
  ([`b61f49e`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/b61f49e9c25d8268ed8bd9b149149fffcafd340d))

- Add scipy-stubs as dev dependency and removed the typings/scipy folder residing in the auxi-mpp
  package
  ([`bed36a2`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/bed36a2ca8fb8d3eb115d439c11bafc025609e1b))

- Add SiO2 to N_tot
  ([`5eca599`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/5eca5998365b75e86f99b3168be919632fad922e))

- Add structural parameter
  ([`42554b4`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/42554b41ac4015ace271093b228ace0f1c7746bb))

- Add tests for more models
  ([`0a5ff8a`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/0a5ff8a75cc69addf840481002c5c32747eb2103))

- Add try except block to multi mv model
  ([`edc1354`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/edc1354f56edb3f2251b4f7e37e00789385f7714))

- Add typings for scipy
  ([`9a6b808`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/9a6b8088809482a1ae4a6199ad013460159c386f))

- Address testing viscosity model functions
  ([`23eaf5f`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/23eaf5f90b690ac0b18821b7125dab873ceda399))

- Address thys comments
  ([`fcf8b92`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/fcf8b923993cb2cca4e07d5e8d668b1f524b7e2c))

- Adjust A_M_Si_R
  ([`92f4bf5`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/92f4bf50647a2eb69a2c262978202366b86d558e))

- Adjust A_M_Si_R
  ([`305b271`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/305b2711efa11ef2ad96c512816e7d3c5161a302))

- Adjust A_M_Si_R
  ([`60de9ef`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/60de9ef2c95d0f00a57ced1d4ef5180534faa6c6))

- Adjust binary viscosity binary parameters
  ([`c8ac255`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/c8ac25573657541d732c0f04a4c5f22f69c9b55c))

- Adjust E
  ([`1567828`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/15678281f5d02b185655f3a504877b68c7dbd904))

- Adjust E_M_Si
  ([`5f479c0`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/5f479c0b16aa8406d06cb399dbf31dc3220844ff))

- Adjust E_M_Si
  ([`a1f818b`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/a1f818b0dfd6e7667ffdf564f2d051054fd8c1d2))

- Adjust E_M_Si
  ([`70eaf3b`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/70eaf3b4da780f95d52c0e050de68ed888c36d9d))

- Adjust E_M_Si_R
  ([`7517d29`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/7517d296c470a44a57d56bac0d7dcf0423c07bb3))

- Adjust unary parameters
  ([`cd6db18`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/cd6db18d0cd86afffc8044f23aecfdebee6c897d))

- Apply fix to viscosity model
  ([`4b6a6d7`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/4b6a6d7ceabb2c21d12829618a57eb51d94a456e))

- Apply fix to viscosity model
  ([`9dd62b2`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/9dd62b2c9c7c4015c0a1a2cda003625c786cf003))

- Apply fix to viscosity model
  ([`c88eca6`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/c88eca61c1dafdf35ed71b4b3ae06afbd95d5158))

- Apply fix to viscosity model
  ([`99cb7a7`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/99cb7a7958344c502d51ce315154d52446f8028b))

- Apply potential fix
  ([`711cca1`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/711cca17264dfd7a298ce1bb86d5bb4312383566))

- Break solve function into 3 parts
  ([`8c21cfa`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/8c21cfad0c9c033f3033e3cdbd99e8b2d5c2a074))

- Calc delta G with struc fracs
  ([`e43500d`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/e43500db87c4ecd51a92b43f63b6908615543f6e))

- Calc deltaG from struct fractions
  ([`52f81e6`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/52f81e61f5468649714a865df8d1259583127f54))

- Calc dG from full frac
  ([`4730232`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/47302320761a747b059b0c99bcf3c7ec6c9d6dcc))

- Calc p after adjustment
  ([`74e2829`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/74e28297d121b52fda2e7277930717bf35dd4e71))

- Calculate delta G from state.x
  ([`e50205f`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/e50205f8a2e4de200aed8311ff9623a8841a921e))

- Change a ternary wording to multi in density model .py file
  ([`fc7f2d7`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/fc7f2d75e56cc8b29ba122a26c5ac123601bb758))

- Change data
  ([`a9278e0`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/a9278e0694ff211640c501d4d98959719d4098dc))

- Change dG calc
  ([`6cebf33`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/6cebf3378dfa0824ae76881c4bfec59eb2fb2e2e))

- Change print
  ([`0f13943`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/0f139433eedbdeaa75873094e02e3eeda2aedbf1))

- Change prints
  ([`921015b`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/921015bb62de06e7f43aacd7dae3e75883924a8e))

- Change test
  ([`3003c08`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/3003c0874143c686ac20350848f0935f272c0793))

- Change test
  ([`ec8b11e`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/ec8b11ea7407cecc3d368f3ad15bc4ef93bfcdd3))

- Change ThibodeauTernary to ThibodeauMulti
  ([`ddc42af`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/ddc42af01c0ef8cefc8a4701e239e34634ba7f02))

- Clean code
  ([`00915f2`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/00915f2f5694743538ef608e8f29c17e2284c694))

- Comment out p_SiSi code
  ([`0cfe5da`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/0cfe5daca6e1ab92d7cadf477a57af29190a646f))

- Complete correction from ruff checks
  ([`501296c`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/501296c6fb9144c08752d5e7ffdcedcb03b4005e))

- Complete correction from ruff checks
  ([`a83b525`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/a83b525fc015fedc9a67a53c1f83ed73c34b1eab))

- Completed pyright issues
  ([`7060a97`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/7060a9793114c57668b75226501008dd305279a1))

- Completed pyright issues
  ([`a61b789`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/a61b789e3333cbadf5e6cfec79b31612ac354a15))

- Convert dictionary key x_b_MM -> M-M
  ([`0993d17`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/0993d174dbc316c645791db32b426e4c9ab622b1))

- Correct bond fraction error key checks
  ([`3f32ce3`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/3f32ce30c0b9904213bef8149bb1e873330901f9))

- Correct pydantic implementation for models' class input
  ([`3e15bcd`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/3e15bcd8ac61127fefdfe5b58cd5ca602f3c0fec))

- Correct pydantic implementation for models' class input
  ([`80f9e7c`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/80f9e7c237c0022aafa622a18c484f5fb038f513))

- Corrected density load import for ThibodeauDensityTernary.load_data()
  ([`9b8cdbd`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/9b8cdbdf5080888a462840f0d747d94dd5eb9da1))

- Dg state.x
  ([`72cf2ba`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/72cf2bafd24077b1c1d492ece352852622f79f17))

- Divide diffusivity into unary, binary and multi
  ([`41c0ebb`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/41c0ebba03fd14e2abea7b6258ca3c0e4299d8a0))

- Divide diffusivity into unary, binary and multi
  ([`8373cb0`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/8373cb0f8f4d12873624d9d2c108fceee3c8653b))

- Divide diffusivity into unary, binary and multi
  ([`78b8c29`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/78b8c290fefb7e143a2f3b001e3282315c789c1d))

- Fix bounds
  ([`c48e928`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/c48e928135d7e4d49db1e4149fef6c752f965051))

- Fix docstrings
  ([`bf12717`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/bf127170eee4e5dc4cc38778da295d2b0f847074))

- Fix math in equation to solve
  ([`922739c`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/922739c62c7c6c78151ea83b45b9673a3684c932))

- Fix mistakes in error handling of bond fractions
  ([`c971dd3`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/c971dd37cb6da8fe9d1ff2831b30c28a0acc2bdf))

- Fix ruff errors
  ([`afb8f9a`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/afb8f9a7374ef9c383105153e744c50d3ab85c87))

- Grundy's way
  ([`5b0acc1`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/5b0acc15feacc10ab1dfad2a791ba1cbbee24da7))

- Grundy's way
  ([`4251b00`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/4251b000b6d1adb1edc4afd1ad98cf6e7ea212a4))

- Grundy's way
  ([`c1d30f2`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/c1d30f26c2b0056d8cd0b7b7d1ab876364cc8762))

- Implement adjusted composition class
  ([`958ab4f`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/958ab4f99e4e4ed0d467e8a1181509eef46ed6f3))

- Implement changes
  ([`d515d01`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/d515d01f1f800300e78ccf5d593ced136062935d))

- Implement changes
  ([`d7bfe92`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/d7bfe92d3643667b07faad295e6fd121535cd78a))

- Implement changes
  ([`aab9e26`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/aab9e2622a840428de36fd0d66b4a58da600e3b2))

- Implement changes
  ([`90fb42e`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/90fb42ed0f4546aa097ccc0144039919142acdc3))

- Implement diffusivity changes into the ec model
  ([`e1c7d78`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/e1c7d78d0058daaf903be8660b6111683792a295))

- Implement diffusivity pytests
  ([`8b262f4`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/8b262f42198d451cb5d5b013d50b31aa2c53b231))

- Implement parameter tests and diffusivity tests
  ([`beb3b78`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/beb3b784b6b9c106693ea3acfdbea2f0fa366e13))

- Implement preliminary pytests
  ([`426b9ab`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/426b9abc4ec9e114a5a3ad7b1786727e2200e0d3))

- Implement shgo without jacobian
  ([`acc2f5c`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/acc2f5c9e8519a057b87e239902d99ae644b1509))

- Implement tests for functions of binary and multi visc models
  ([`9d8f28d`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/9d8f28dd1296d4fdc02b8e6b1998bcc594237c85))

- Implement Tpx states
  ([`19dfd12`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/19dfd124762bab76928043f6f29601df25a20ab0))

- Implement Tpx states
  ([`79de9da`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/79de9dad41cc0e06d7da308560016dc806325160))

- Import changes
  ([`0d62b3e`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/0d62b3e98fa4443b98ee44d303080f899a3c5acb))

- Improve error handling of bond fractions for SilicateBinarySlagEquilibriumTxState and
  SilicateSlagEquilibriumTxState classes
  ([`0f8933f`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/0f8933f65fb4c59a190bfdb40cc9f364dd93b2aa))

- Insert print statements for testing
  ([`df5c36d`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/df5c36d060931d7f4e4d73eca9a6e6ad69eb1a9e))

- Kim's way
  ([`4cc44c6`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/4cc44c685aa1704436d910c0a4d48f5ce8a47562))

- Kim's way
  ([`0acba46`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/0acba46c00ee990f9271964a4ee09985ee7858d9))

- Kim's way
  ([`0e1e78e`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/0e1e78ec5756f58d450be086dff3e217e127ec28))

- Kim's way
  ([`ae8a761`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/ae8a7614cd3c55a46a5b104a96f0a5050b0cb73a))

- Multiply non-SiO2 molar volume by oxygen count
  ([`7a2134e`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/7a2134eb22fd2080067fb2fb38039aadfaa31e83))

- Neg dG
  ([`7e94a05`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/7e94a05f0ac4fd0e02087caf74c1acb60ca871a7))

- Nge dG CaO
  ([`a71be8e`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/a71be8ef52759f1c43cb5b4abd8f0b8d4a4c9d58))

- Original parameters
  ([`f85613f`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/f85613fca075c4d37916e3c4e99af92e514305d1))

- Plus G
  ([`0f17968`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/0f179682cc890e9a19b1f4763d7506b9d758d1a7))

- Positive dG
  ([`42177ff`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/42177ff6d66e652fa343d83f6d3e621e364e7e4b))

- Print(r)
  ([`72aed7f`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/72aed7f0d202d28d3b184106b7c229b8074a9eb1))

- Redefine equations to solve to prevent division by 0 error
  ([`dbaeade`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/dbaeaded5ccde4b13676c2b0962cf5e16c8c0cc3))

- Refine dG's calculation
  ([`d9fe22c`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/d9fe22c294a8ebd5fa3f1b92074d72ea09f92b12))

- Refine pytests mv
  ([`3c0ef54`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/3c0ef549f8daa99b5e3ea359a3f5deeb26e7f704))

- Remove almost all but shgo typing files
  ([`3fd7091`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/3fd7091c8a4fa30432740df9c6e39531c53dd9ef))

- Remove almost all but shgo typing files
  ([`f66e12c`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/f66e12cec5cc6ed59b2ef5ebdb98bb7d4dee7e33))

- Remove mass balance check
  ([`d4e7e6c`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/d4e7e6cedb115566ab78985421b3a7acecf8d9fa))

- Remove more unnecessary typing files
  ([`7f5783c`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/7f5783cc70ae2d50c2f25db2a1e59a93665ba1bd))

- Remove old ternary viscosity model
  ([`b3d73f5`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/b3d73f5b9a84db616bd009462ed169eb7e49ad2c))

- Remove print statements
  ([`a33c6a6`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/a33c6a6fb0e1ce16583e3014bb764a2083637eb6))

- Remove print statements
  ([`dcf41eb`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/dcf41ebd0cb63b915af3895b21d8befe690a154d))

- Remove prints
  ([`20543ce`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/20543ce87e1e8b95c7a17a86a611a58869cae87d))

- Remove sympy dependency
  ([`2cb8807`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/2cb880761c3dcd360aaad5269e52661c72dfdbcf))

- Remove temporary test and print statements
  ([`c246093`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/c2460939e3fb6557e405bd3369ec57e540f29c4e))

- Remove update functions from SilicateBinarySlagEquilibriumTxState and
  SilicateSlagEquilibriumTxState classes
  ([`43999fa`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/43999fa8239278287b3d311b690bd8d45fff19af))

- Reset parameters
  ([`bb655c0`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/bb655c05b35f383bc5204c3f47ccd466d6b5e9c2))

- Return kim's p
  ([`14091b8`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/14091b89027846d9f6f02db8e977abd6aca6a27a))

- Return to Grundy's way of calculating p
  ([`cedf0fc`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/cedf0fc770636faf7e073d2beab2a9c576cb40aa))

- Reverse tests
  ([`12c6312`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/12c6312b1012797157fcb4d5276300f840ec0749))

- Revert neg dG cao
  ([`34a004d`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/34a004d16325282532e2971ddb818e90a9de85de))

- Revert ruff prescription
  ([`db151c8`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/db151c8eb84f172e05e4e47cfab2f41528a973a9))

- Revert test
  ([`0ced74c`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/0ced74c21ebc00690c40f6071bda167ed2b6440f))

- Revert tests
  ([`13ba199`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/13ba199aca64439377812fe85cd0cbe54265b8ad))

- Revert to normal auxi-mpp
  ([`83bc0b5`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/83bc0b5bb46c629fe254f3b5d3572bea8feec0bd))

- Ruff formatting
  ([`752e67d`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/752e67d82d43fe5e6d32df8edb72e4587f939279))

- Ruff formatting
  ([`2051218`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/2051218991378d820a82cfd83c34c3e043970872))

- Ruff initial fixes
  ([`c9286e7`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/c9286e7d0761ba5a3f969e7342a2590c31eeeee1))

- Ruff initial fixes
  ([`ddf6487`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/ddf6487653c4f9f50e0a3d241d6151c904c5ceb6))

- Ruff initial fixes
  ([`c64c13c`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/c64c13c84a985a49c25c447dc6d4fa335f2c6824))

- Set + G
  ([`8ebcee0`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/8ebcee08dda0f6f104483f908d655b382b5bb4b4))

- Set -13000 dG
  ([`8871395`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/8871395d0e0cd2923ff4953aad6fb07ab281cbf9))

- Set dG
  ([`ce47256`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/ce472562eb932c23e5208ed1df50e6809a9b7a55))

- Set negative delta G
  ([`9ce023f`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/9ce023fb7e2044f14fa8ea216783e5307fc5d7af))

- Skip tests that fails due to the shgo solver failing
  ([`8321db9`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/8321db90a4d44ba8b7574f5f6d3944198b730e8e))

- Small change
  ([`eb65b6c`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/eb65b6c438216c5aa7e6ad85aa49ea527bf467e8))

- Small change
  ([`2ddecf2`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/2ddecf2acec43e378d0bcdc59114a2ecdb743dc8))

- Small change
  ([`4306ada`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/4306ada7455a805203c020fcfce9690aab580292))

- Small change
  ([`53e22af`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/53e22af97c30dff4ef783beeec6dbfb8992ae59a))

- Small fix
  ([`cc96573`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/cc96573102915b03399ae6a1e7524b9134b1f375))

- Small fix
  ([`f973c5c`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/f973c5cf2f93996c9342dbc46081d75b74a1092d))

- Small fix
  ([`5dfbab8`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/5dfbab8943c84962f8b7608037a5b3b9e2b6d119))

- Small fix
  ([`457da95`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/457da9533aa9c7373f52aafc909af77d2bcf6a0d))

- Small fix
  ([`fa14887`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/fa14887f402f01ef89641efac9d0bdc8827e864d))

- Small fix
  ([`b8e09af`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/b8e09af99328eb594ed2827bbd0c1fe95cd8a2e4))

- Small fix
  ([`f6027e1`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/f6027e11ee3106a205a9210d805ed8f6ecd2d6d7))

- Small fix
  ([`fff1885`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/fff188560213dea4095f73371ce77e6baa94f13c))

- Solve boundry cond problem
  ([`384c9f8`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/384c9f899913dad4bbb7197b106687136d7a5158))

- Solve pyright ruff issues
  ([`8180071`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/8180071e004937d62af79102f6009e2744722627))

- Successfully tested multi visc model with sympy solver
  ([`043d663`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/043d6636db255b22998d76718d963e0092fca0b8))

- Test
  ([`4303e3a`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/4303e3a57e676ee6e118214af26d91d41d2917fb))

- Test
  ([`e2096ea`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/e2096eada8180fa7e095ebce2bc5fd070ff38935))

- Test
  ([`bedca2e`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/bedca2e47c62b8ed3cd65c5b7464b823b9abc61d))

- Test
  ([`de474cd`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/de474cd4c77112fe7e2cc408f701662521ccae2f))

- Test
  ([`8257a45`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/8257a45e81d9b36e0c27016d262222500178990c))

- Test
  ([`966bf6e`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/966bf6efec05d08ae2ba2db37ac0f4806d614d90))

- Test
  ([`4b5df31`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/4b5df31e8494e2ec1beca81c325fb092528d6a14))

- Test
  ([`390752b`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/390752b014ba3f036445635b7b9aa7f4bfef28aa))

- Test
  ([`3998259`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/39982599be1fabcedcc49e620db7d62b58b2df0c))

- Test
  ([`1ae62dd`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/1ae62dd3e29de9e313b238b131a31807c6125093))

- Test
  ([`aadb872`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/aadb872fd7c9613f3b63b87b8bcdd2200ad0fec5))

- Test
  ([`7891246`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/7891246a4c7399e54f05a5aa69bcaa2e8341f45b))

- Test
  ([`0023bd2`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/0023bd2b9af5c991bbc0e020bfd3c3170a219365))

- Test
  ([`2fa2980`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/2fa29803223e8a37ab3d2f4094eb2e15f29c149e))

- Test
  ([`9cb1fa3`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/9cb1fa3d3df1861c34d916960e778ab1a4584b42))

- Test
  ([`ac5b755`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/ac5b755776909436b03830a8d2a0983396a6a33c))

- Test
  ([`23eac0b`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/23eac0b892183070e8e798fb8c7f2203d9cc4c9b))

- Test
  ([`1c861e0`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/1c861e0eeef4a99fd6dd9c43c8f98041b9abed45))

- Test
  ([`4808dfb`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/4808dfbb45d0b73ae291db70aec671ee7713a907))

- Test
  ([`912cc70`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/912cc7037db9482ad0ab03ab4c8124919901a54b))

- Test
  ([`6c37118`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/6c37118fa7b87c2fc7652841aee1bcf155add659))

- Test
  ([`023b7f1`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/023b7f1b9e379059deb674027a509265d200afef))

- Test
  ([`e7e804e`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/e7e804e76a07ee9a6901a36b95ecd865236ac856))

- Test
  ([`6e82b73`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/6e82b731e9a88f6a9848706d0d6e6593afbc72d7))

- Test
  ([`b3beed0`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/b3beed009693e4c1d8f21874c1995d51854ca5f9))

- Test
  ([`492815a`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/492815a77f35e2ec40c2cf91aa00b3a0ca9ef601))

- Test
  ([`0a6f8ec`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/0a6f8ec2ace854ae00be57a94c7ddf91c40cedd6))

- Test
  ([`063f641`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/063f641e813c5f3d4fdb2634e774cbc59f819501))

- Test
  ([`578c0ae`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/578c0ae4b2d74d99d9da9bd268e9edad8edcc31c))

- Test
  ([`0e6933a`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/0e6933a085da39ed615b02d0c6f1ad4e5b57401e))

- Test
  ([`1d9c1f4`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/1d9c1f413cb2ec577642d5f277c3695a649a2fd4))

- Test
  ([`8288c83`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/8288c838cf8da0f21cf017fd7375694cc2beaafd))

- Test
  ([`daf34f8`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/daf34f8094744954d552ba8e99bb16aaa6d8a879))

- Test change
  ([`1dd3fab`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/1dd3fab1da8f40927e315dbd8f275a7f8600354b))

- Test data
  ([`45a011b`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/45a011b2e670d8438725ab3853b418404e92c4fa))

- Test error handling
  ([`e79364c`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/e79364c685eac28e0c6b9b28d15a3713bc5a807a))

- Test first solution
  ([`212fc27`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/212fc27e74ad3f5cd5d50fe95ac3e1cf98142a9c))

- Test new R
  ([`7c48db8`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/7c48db841e494ac3133f1f28161b0b3a714aebd1))

- Test second solution
  ([`d3de80c`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/d3de80cb2028d0faf88e3b2e2bec85f07a46f6af))

- Test shgo on simpler function
  ([`9d4b25c`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/9d4b25c3844afdb46d6e29fc6737ca91e9f8fffe))

- Test sympy solver
  ([`2be78a3`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/2be78a3bedc17c183794c3498b1cdc5c20acd9d9))

- Test ternary systems bond fraction error handling
  ([`c34afa4`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/c34afa41b0cc1818be45ccc025e6e622ed19e38d))

- Tests
  ([`7abb47d`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/7abb47dc1aeb0b4e4074b50d4b1b184e1c9d2e5c))

- Type: ignores
  ([`1e93659`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/1e936596696209ad713a8dc2d2100fbefb3a414c))

- Update auxi-chemistry dependency
  ([`31180ab`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/31180ab11a28bb091ae3b995ef5685009e3a43fb))

- Update auxi-chemistry dependency
  ([`03b8546`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/03b85469438f5c68360930c540999e6266eafddc))

- Update bounds
  ([`30e096d`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/30e096d079a7587ce03d027efb8d972235367702))

- Update call function
  ([`f1f3b6d`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/f1f3b6de6375e170aecd16a49505a52dc5ff07cd))

- Update call function
  ([`70c056d`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/70c056dbb1faffeadfda073bc2460ba10b0c6236))

- Update inputs
  ([`26a584d`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/26a584d21f0ca1389cef6e679cc006cfccf8cff3))

- Update inputs
  ([`cdccf97`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/cdccf97d88b10a8dd28cc32515b4ca4e01ce79a9))

- Update inputs
  ([`e1d6d93`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/e1d6d93a81668602ee5cb71041c0d262a0aa9174))

- Update inputs
  ([`14e04ac`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/14e04ac364435d6cec192612deaa4d2f73685b36))

- Update lint rules
  ([`700b71d`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/700b71d15ea008771e6b83acd976f4d7f00fcf90))

- Update lint rules
  ([`63299a9`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/63299a910bbc78c3710e4f1490fbb7778577ac81))

- Use grundy's way to calc X_star
  ([`34eb6ad`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/34eb6ad3b48ddf3d3700142adc7ae87bee46d5b0))

- Uv add sympy
  ([`5bbc81b`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/5bbc81bfeb6f7a6eda6622b3a809732edf052192))

### Continuous Integration

- Update deploy steps
  ([`087d47e`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/087d47e975daeca53bc1b9a75fcb5d1283754e8c))

- Update deploy steps
  ([`0022a4d`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/0022a4d89c4698dfa1e171dee4a9a432a370c828))

### Features

- Implement multicomp viscosity model
  ([`8b78332`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/8b78332160d4bf0ae6c7b40ad705927220515f88))

- Implement new ui for all models
  ([`01abc9d`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/01abc9df71385e6b8791b51668e0044f09111890))

- Implement new ui for all models
  ([`4687c29`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/4687c2988b39919a6e2b0a181d855d7df8433fb0))

- Implement new ui for all models
  ([`44353bd`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/44353bd46ac829a4fa3e52ef8818fc9daaae6854))

- Implement new ui for all models
  ([`743abda`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/743abda2606ccc57c004170635319bbd617b1ede))

- Successfully implement multicomponent viscosity model
  ([`cbe9a1d`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/cbe9a1d5ca5fe0a6eceb27de027073c80ab8a4b3))


## v2.0.3 (2025-02-10)

### Bug Fixes

- Update docstrings
  ([`3b8ca72`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/3b8ca7275ea4782e481ee4c33ad397938202c186))

### Chores

- Remove 'compound' as arg from docstring
  ([`ffaa5e6`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/ffaa5e6873a4f355c4436426f1b043d582ca1d61))

- Remove tstate update method
  ([`13ecebf`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/13ecebfea9b71d0d269fc57844f3d167444eca4f))

- Resolve pyright issues
  ([`9851c78`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/9851c78e11467d51d396dab5b4598ccaab65ece3))

- Small comment change
  ([`f42c292`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/f42c292b4279416cd1ce4b2201cfae80a61f60eb))

- Update docstrings raises
  ([`ef2e4bd`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/ef2e4bdad05720628185855c594472b1a2ca44cc))

- Update models docstrings
  ([`eed8388`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/eed83889be850ef758e737454619c984a1bd7978))

- Update readme
  ([`f5d2b7e`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/f5d2b7ee4950e28723f90bcd1da8bf0c333e551c))

- Update readme
  ([`34bb675`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/34bb67548aa1ae1204f445b7e7b65341a7de45d8))


## v2.0.2 (2025-02-04)

### Bug Fixes

- Update license
  ([`d213bc3`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/d213bc362ced4aa9c491f4c218787b074efbb272))


## v2.0.1 (2025-02-04)

### Bug Fixes

- Add license
  ([`b70ae61`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/b70ae61827ebef7f353cf9c6a6957f69a42ad0a8))


## v2.0.0 (2025-02-04)

### Chores

- Pin version to 2.0.0
  ([`b46cc7a`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/b46cc7a5bb8847da7b6eaf67043a35e076220387))


## v0.0.0 (2025-02-04)

### Chores

- Add docs for using and contributing
  ([`fa237f7`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/fa237f75de793c9f11edf723a78ca349a85d7c88))

- First commit
  ([`aabc549`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/aabc54915bf1945ff43d7d2f5b5de5dd362c0a1f))

- Pre-commit
  ([`d9d86d2`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/d9d86d2d5b78f0057cd286fa6fa78652a786f823))

- Remove lookup material states
  ([`2c5e0ee`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/2c5e0eed4d66b9f793a1b6b4272815b33c71be9f))

- Remove typings
  ([`41230dc`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/41230dcaa2b56f3074508f52dcd52dda7f73914b))

- Update docs for contributing
  ([`9ee5231`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/9ee5231c98d550f23c881975f926a37bfbca73ae))

- Update states
  ([`bfbedd2`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/bfbedd25e264a345db58d155500046c2a87cb04e))

### Continuous Integration

- Add credentials for gitlab pypi access
  ([`79783b9`](https://gitlab.collab.ex-mente.com/auxi-oss/auxi-mpp/-/commit/79783b9ce148501763911d5aa28893681f13097c))
